==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_fields/MAINTENANCEPATTERNID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour MAINTENANCEPATTERNID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="MAINTENANCEPATTERNID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MAINTENANCEPATTERNCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MAINTENANCEPATTERNREVISION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MAINTENANCEPATTERNID_Type", propOrder = {
    "maintenancepatterncode",
    "maintenancepatternrevision",
    "organizationid",
    "description"
})
public class MAINTENANCEPATTERNID_Type {

    @XmlElement(name = "MAINTENANCEPATTERNCODE", required = true)
    protected String maintenancepatterncode;
    @XmlElement(name = "MAINTENANCEPATTERNREVISION", defaultValue = "0")
    protected long maintenancepatternrevision;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété maintenancepatterncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMAINTENANCEPATTERNCODE() {
        return maintenancepatterncode;
    }

    /**
     * Définit la valeur de la propriété maintenancepatterncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMAINTENANCEPATTERNCODE(String value) {
        this.maintenancepatterncode = value;
    }

    /**
     * Obtient la valeur de la propriété maintenancepatternrevision.
     * 
     */
    public long getMAINTENANCEPATTERNREVISION() {
        return maintenancepatternrevision;
    }

    /**
     * Définit la valeur de la propriété maintenancepatternrevision.
     * 
     */
    public void setMAINTENANCEPATTERNREVISION(long value) {
        this.maintenancepatternrevision = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/MAINTENANCEPATTERNID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for MAINTENANCEPATTERNID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="MAINTENANCEPATTERNID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MAINTENANCEPATTERNCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MAINTENANCEPATTERNREVISION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MAINTENANCEPATTERNID_Type", propOrder = {
    "maintenancepatterncode",
    "maintenancepatternrevision",
    "organizationid",
    "description"
})
public class MAINTENANCEPATTERNID_Type {

    @XmlElement(name = "MAINTENANCEPATTERNCODE", required = true)
    protected String maintenancepatterncode;
    @XmlElement(name = "MAINTENANCEPATTERNREVISION", defaultValue = "0")
    protected long maintenancepatternrevision;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the maintenancepatterncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMAINTENANCEPATTERNCODE() {
        return maintenancepatterncode;
    }

    /**
     * Sets the value of the maintenancepatterncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMAINTENANCEPATTERNCODE(String value) {
        this.maintenancepatterncode = value;
    }

    /**
     * Gets the value of the maintenancepatternrevision property.
     * 
     */
    public long getMAINTENANCEPATTERNREVISION() {
        return maintenancepatternrevision;
    }

    /**
     * Sets the value of the maintenancepatternrevision property.
     * 
     */
    public void setMAINTENANCEPATTERNREVISION(long value) {
        this.maintenancepatternrevision = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
